@@ -39,15 +39,15 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'euphorie'
-copyright = '2009-2010, Simplon'
+copyright = '2009-2011, Simplon B.V.'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '2.2'
+version = '2.4'
 # The full version, including alpha/beta/rc tags.
-release = '2.2.1'
+release = '2.4'
 
 # There are two options for replacing |today|: either, you set today to
 # some non-false value, then it is used:
