@@ -44,7 +44,7 @@ class IRisk(form.Schema, IRichDescription, IBasic):
 
     problem_description = schema.TextLine(
             title = _("label_problem_description",
-                    default=u"Problem description"),
+                    default=u"Inversed statement"),
             description = _("help_problem_description",
                     default=u"This is the inverse of the statement: a "
                             u"short description of current (bad) situation."),
@@ -62,7 +62,7 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     form.order_after(description="problem_description")
 
     legal_reference = HtmlText(
-            title = _("label_legal_reference", default=u"Legal and policy references."),
+            title = _("label_legal_reference", default=u"Legal and policy references"),
             required=False)
     form.widget(legal_reference="plone.app.z3cform.wysiwyg.WysiwygFieldWidget")
     form.order_after(legal_reference="description")
